@@ -2,7 +2,7 @@ use crate::util::field_not_ignored;
 use heck::CamelCase;
 use proc_macro2::{Ident, TokenStream};
 use quote::{format_ident, quote, quote_spanned};
-use syn::{Data, DataStruct, Field, Fields, Type};
+use syn::{punctuated::Punctuated, token::Comma, Data, DataStruct, Field, Fields, Lit, Meta, Type};
 
 pub fn expand_derive_active_model(ident: Ident, data: Data) -> syn::Result<TokenStream> {
     let fields = match data {
@@ -28,7 +28,36 @@ pub fn expand_derive_active_model(ident: Ident, data: Data) -> syn::Result<Token
     let name: Vec<Ident> = fields
         .clone()
         .into_iter()
-        .map(|Field { ident, .. }| format_ident!("{}", ident.unwrap().to_string().to_camel_case()))
+        .map(|field| {
+            let mut ident = format_ident!(
+                "{}",
+                field.ident.as_ref().unwrap().to_string().to_camel_case()
+            );
+            for attr in field.attrs.iter() {
+                if let Some(ident) = attr.path.get_ident() {
+                    if ident != "sea_orm" {
+                        continue;
+                    }
+                } else {
+                    continue;
+                }
+                if let Ok(list) = attr.parse_args_with(Punctuated::<Meta, Comma>::parse_terminated)
+                {
+                    for meta in list.iter() {
+                        if let Meta::NameValue(nv) = meta {
+                            if let Some(name) = nv.path.get_ident() {
+                                if name == "enum_name" {
+                                    if let Lit::Str(litstr) = &nv.lit {
+                                        ident = syn::parse_str(&litstr.value()).unwrap();
+                                    }
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+            ident
+        })
         .collect();
 
     let ty: Vec<Type> = fields.into_iter().map(|Field { ty, .. }| ty).collect();
